package com.bonus.canteen.core.basic.mapper;

import java.util.List;
import com.bonus.canteen.core.basic.domain.BasicStall;

/**
 * 档口信息Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface BasicStallMapper {
    /**
     * 查询档口信息
     * 
     * @param stallId 档口信息主键
     * @return 档口信息
     */
    public BasicStall selectBasicStallByStallId(Long stallId);

    public BasicStall selectBasicStallByStallName(BasicStall allocStall);

    public int selectBasicStallCountByCanteenIds(Long[] canteenIds);

    /**
     * 查询档口信息列表
     * 
     * @param basicStall 档口信息
     * @return 档口信息集合
     */
    public List<BasicStall> selectBasicStallList(BasicStall basicStall);

    /**
     * 新增档口信息
     * 
     * @param basicStall 档口信息
     * @return 结果
     */
    public int insertBasicStall(BasicStall basicStall);

    /**
     * 修改档口信息
     * 
     * @param basicStall 档口信息
     * @return 结果
     */
    public int updateBasicStall(BasicStall basicStall);

    /**
     * 删除档口信息
     * 
     * @param stallId 档口信息主键
     * @return 结果
     */
    public int deleteBasicStallByStallId(Long stallId);

    /**
     * 批量删除档口信息
     * 
     * @param stallIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasicStallByStallIds(Long[] stallIds);
}
