package com.bonus.canteen.core.basic.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.basic.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.basic.domain.BasicStall;
import com.bonus.canteen.core.basic.service.IBasicStallService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 档口信息Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "档口信息接口")
@RestController
@RequestMapping("/basic_stall")
public class BasicStallController extends BaseController {
    @Autowired
    private IBasicStallService basicStallService;

    /**
     * 查询档口信息列表
     */
    @ApiOperation(value = "查询档口信息列表")
    //@RequiresPermissions("basic:stall:list")
    @GetMapping("/list")
    public TableDataInfo list(BasicStall basicStall) {
        startPage();
        List<BasicStall> list = basicStallService.selectBasicStallList(basicStall);
        return getDataTable(list);
    }

    /**
     * 导出档口信息列表
     */
    @ApiOperation(value = "导出档口信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:stall:export")
    @SysLog(title = "档口信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出档口信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicStall basicStall) {
        List<BasicStall> list = basicStallService.selectBasicStallList(basicStall);
        ExcelUtil<BasicStall> util = new ExcelUtil<BasicStall>(BasicStall.class);
        util.exportExcel(response, list, "档口信息数据");
    }

    /**
     * 获取档口信息详细信息
     */
    @ApiOperation(value = "获取档口信息详细信息")
    //@RequiresPermissions("basic:stall:query")
    @GetMapping(value = "/{stallId}")
    public AjaxResult getInfo(@PathVariable("stallId") Long stallId) {
        return success(basicStallService.selectBasicStallByStallId(stallId));
    }

    /**
     * 新增档口信息
     */
    @ApiOperation(value = "新增档口信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:stall:add")
    @SysLog(title = "档口信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增档口信息")
    @PostMapping
    public AjaxResult add(@RequestBody BasicStall basicStall) {
        try {
            return toAjax(basicStallService.insertBasicStall(basicStall));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改档口信息
     */
    @ApiOperation(value = "修改档口信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:stall:edit")
    @SysLog(title = "档口信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改档口信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody BasicStall basicStall) {
        try {
            return toAjax(basicStallService.updateBasicStall(basicStall));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除档口信息
     */
    @ApiOperation(value = "删除档口信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("basic:stall:remove")
    @SysLog(title = "档口信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除档口信息")
	@PostMapping("/del/{stallIds}")
    public AjaxResult remove(@PathVariable Long[] stallIds) {
        return toAjax(basicStallService.deleteBasicStallByStallIds(stallIds));
    }
}
